from .detoxify import (
    Detoxify,
    multilingual_toxic_xlm_r,
    toxic_albert,
    toxic_bert,
    unbiased_albert,
    unbiased_toxic_roberta,
)

__all__ = [
    "Detoxify",
    "toxic_bert",
    "toxic_albert",
    "unbiased_toxic_roberta",
    "unbiased_albert",
    "multilingual_toxic_xlm_r",
]



#!/usr/bin/env python

from setuptools import find_packages, setup

with open("README.md") as fh:
    long_description = fh.read()

setup(
    name="detoxify",
    version="0.5.1",
    description="A python library for detecting toxic comments",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Unitary",
    author_email="laura@unitary.ai",
    url="https://github.com/unitaryai/detoxify",
    install_requires=[
        "transformers == 4.22.1",  # pin to this version due to #75
        "torch >= 1.7.0",
        "sentencepiece >= 0.1.94",
    ],
    packages=find_packages(include=["detoxify"], exclude=["tests", "src"]),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
